[![](https://img.shields.io/badge/Python-3.10-blue.svg)]()
[![](https://img.shields.io/badge/Documentation-unfinished-orange.svg)]()
[![](https://img.shields.io/badge/build-passing-green.svg)]()

# GFAgraphs

This package aims to be an abstraction layer for GFA file format.

Its a simple, convinient but lack-luster library to extract informations from GFA files, be it as the graph or line level.

Main features are :
+ **Record** (line-level) and **Graph** (file-level) abstractions
+ Full decoding of **GFA tags** (standard+optional)
+ **pip**-installable (`pip install gfagraphs`)
+ **networkx** integration


